pub struct ItemToFile {
pub item: Item,
}Expand description
This implementor targets any item inside a complete AST.
When it’s used with Finder, it doesn’t take attributes into account, this is, if the
following is contained in the target AST
/// Some nice docs
#[some_attr]
type Type = ();and the target item is type Type = ();, the [find] method will return true. A major update
will change this in the future, allowing to include attributes in the lookup if needed.
Fields
item: ItemTrait Implementations
Sourceimpl Clone for ItemToFile
impl Clone for ItemToFile
Sourcefn clone(&self) -> ItemToFile
fn clone(&self) -> ItemToFile
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ItemToFile
impl Debug for ItemToFile
Sourceimpl From<Item> for ItemToFile
impl From<Item> for ItemToFile
Sourceimpl<'a> ToFind<'a, ItemToFile, 1> for Finder<'a, EmptyFinder, 1>
impl<'a> ToFind<'a, ItemToFile, 1> for Finder<'a, EmptyFinder, 1>
fn to_find(self, finder: &'a ItemToFile) -> Finder<'a, ItemToFile, 1>
Sourceimpl<'a> ToMutate<'a, ItemToFile, 1> for Mutator<'_, EmptyMutator, 1>
impl<'a> ToMutate<'a, ItemToFile, 1> for Mutator<'_, EmptyMutator, 1>
fn to_mutate(self, mutator: &'a ItemToFile) -> Mutator<'a, ItemToFile, 1>